pub enum DrawRegion {
Global,
PaddedLocal(PaddingRect),
Absolute(PxRect),
}Expand description
Defines the drawing region for a rendering command.
Variants
Global
The command draws to the entire surface.
PaddedLocal(PaddingRect)
The command draws to a region relative to its own bounding box.
Absolute(PxRect)
The command draws to a specific, absolute region of the screen.