pub enum SampleRegion {
Global,
PaddedLocal(PaddingRect),
Absolute(PxRect),
}Expand description
Defines the sampling requirements for a rendering command that needs a barrier.
Variants
Global
The command needs to sample from the entire previously rendered scene. This will cause a full-screen texture copy.
PaddedLocal(PaddingRect)
The command needs to sample from a region relative to its own bounding box.
Absolute(PxRect)
The command needs to sample from a specific, absolute region of the screen.
Implementations
Sourceimpl SampleRegion
impl SampleRegion
Sourcepub const ZERO_PADDING_LOCAL: Self
pub const ZERO_PADDING_LOCAL: Self
A zero-padding local barrier requirement for commands that only sample within their bounds.
Sourcepub const fn uniform_padding_local(padding: Px) -> Self
pub const fn uniform_padding_local(padding: Px) -> Self
Creates a PaddedLocal barrier requirement with uniform sampling
padding on all sides.